@@ -1,6 +1,6 @@
 import re, json
 from datetime import date
-from https import idk
+from .https import idk
 requests = idk()
 get = idk().get
 #cars of nitrotype
